@@ -96,7 +96,7 @@ from etmTk.data import (
     getFileTuples,
     hsh2str,
     import_ical,
-    parse_dt,
+    parse_str,
     parse_period,
     relpath,
     rrulefmt,
@@ -110,7 +110,7 @@ ALLREPS = _('all repetitions')
 MESSAGES = _('Error messages')
 VALID = _("Valid entry")
 FOUND = "found"  # for found text marking
-FINISH = _("Finish")
+FINISH = _("Save and Close")
 
 # MAKE = _("Make")
 PRINT = _("Print")
@@ -185,8 +185,11 @@ class SimpleEditor(Toplevel):
         self.parent = parent
         self.loop = parent.loop
         BGCOLOR = self.loop.options['background_color']
+        self.BGCOLOR = BGCOLOR
         HLCOLOR = self.loop.options['highlight_color']
+        self.HLCOLOR = HLCOLOR
         FGCOLOR = self.loop.options['foreground_color']
+        self.FGCOLOR = FGCOLOR
         self.configure(background=BGCOLOR, highlightcolor=HLCOLOR)
         self.messages = self.loop.messages
         self.messages = []
@@ -229,8 +232,7 @@ class SimpleEditor(Toplevel):
         # finish will evaluate the item entry and, if repeating, show reps
         finish = ttk.Button(frame, text=FINISH, style="bg.TButton", command=self.onFinish)
         finish.pack(side=RIGHT, padx=4)
-        # self.bind("<Control-w>", self.onCheck)
-        self.bind("<Control-w>", self.onFinish)
+        self.bind("<Control-s>", self.onFinish)
 
 
         # find
@@ -623,8 +625,8 @@ class SimpleEditor(Toplevel):
                         reps = SOMEREPS
                     prompt = "{0}, {1}:\n\n  {2}".format(prompt, reps, "\n  ".join(repsfmt))
             else:
-                repetitions = "No repetitions were generated."
-                self.loop.messages.append(repetitions)
+                warn = "No repetitions were generated.\nConsider removing the @r entry."
+                prompt = prompt + "\n\n" + warn
             if self.loop.messages:
                 messages = "{0}".format("\n".join(self.loop.messages))
                 logger.debug("messages: {0}".format(messages))
@@ -688,7 +690,10 @@ class SimpleEditor(Toplevel):
             logger.debug('done')
 
     def messageWindow(self, title, prompt, opts=None, height=8, width=52):
-        win = Toplevel(self)
+        win = Toplevel(self,
+                highlightcolor=self.HLCOLOR,
+                background=self.BGCOLOR,
+                highlightbackground=self.BGCOLOR)
         win.title(title)
         win.geometry("+%d+%d" % (self.text.winfo_rootx() + 50, self.text.winfo_rooty() + 50))
         f = Frame(win)
@@ -696,6 +701,7 @@ class SimpleEditor(Toplevel):
         b = ttk.Button(win, text=_('OK'),style="bg.TButton", command=win.destroy)
         b.pack(side='bottom', fill=tkinter.NONE, expand=0, pady=0)
         win.bind('<Return>', (lambda e, b=b: b.invoke()))
+        win.bind('<KP_Enter>', (lambda e, b=b: b.invoke()))
         win.bind('<Escape>', (lambda e, b=b: b.invoke()))
         tkfixedfont = tkFont.nametofont("TkFixedFont")
         if 'fontsize_fixed' in self.loop.options and self.loop.options['fontsize_fixed']:
@@ -705,9 +711,9 @@ class SimpleEditor(Toplevel):
             f, wrap="word", padx=2, pady=2, bd=2, relief="sunken",
             font=tkfixedfont,
             height=height,
-            background=BGCOLOR,
-            highlightcolor=HLCOLOR,
-            foreground=FGCOLOR,
+            background=self.BGCOLOR,
+            highlightcolor=self.HLCOLOR,
+            foreground=self.FGCOLOR,
             width=width,
             takefocus=False)
         t.insert("0.0", prompt)
@@ -1397,13 +1403,13 @@ class ReadOnlyText(Text):
 class MessageWindow():
     # noinspection PyShadowingNames
     def __init__(self, parent, title, prompt, opts={}):
-        self.win = Toplevel(parent)
-        self.win.protocol("WM_DELETE_WINDOW", self.cancel)
-        self.parent = parent
         self.loop = parent.loop
         BGCOLOR = self.loop.options['background_color']
         HLCOLOR = self.loop.options['highlight_color']
         FGCOLOR = self.loop.options['foreground_color']
+        self.win = Toplevel(parent, highlightcolor=HLCOLOR, background=BGCOLOR)
+        self.win.protocol("WM_DELETE_WINDOW", self.cancel)
+        self.parent = parent
         self.options = opts
         self.win.title(title)
         tkfixedfont = tkFont.nametofont("TkFixedFont")
@@ -1644,10 +1650,8 @@ class FileChoice(object):
 
 class Dialog(Toplevel):
 
-    BGCOLOR = None
-
-    def __init__(self, parent, title=None, prompt=None, opts=None, default=None, modal=True, xoffset=50, yoffset=50, event=None, process=None, font=None):
-        global BGCOLOR
+    def __init__(self, parent, title=None, prompt=None, opts=None, default=None, modal=True, xoffset=50, yoffset=50, event=None, process=None, font=None, close=0):
+        # global BGCOLOR, HLCOLOR, FGCOLOR
         self.parent = parent
         self.loop = parent.loop
         BGCOLOR = self.loop.options['background_color']
@@ -1691,10 +1695,13 @@ class Dialog(Toplevel):
         self.protocol("WM_DELETE_WINDOW", self.quit)
         if parent:
             self.geometry("+%d+%d" % (parent.winfo_rootx() + xoffset, parent.winfo_rooty() + yoffset))
+        if close:
+            self.after(close, lambda: self.cancel())
         if modal:
             self.grab_set()
             self.wait_window(self)
 
+
     def body(self, master):
         # create dialog body.  return widget that should have
         # initial focus.  this method should be overridden
@@ -1709,6 +1716,7 @@ class Dialog(Toplevel):
         w = ttk.Button(box, text="Cancel", style="bg.TButton",  command=self.cancel)
         w.pack(side="right", padx=5, pady=2)
         self.bind("<Return>", self.ok)
+        self.bind("<KP_Enter>", self.ok)
         self.bind("<Escape>", self.cancel)
 
         box.pack(side='bottom')
@@ -1780,6 +1788,7 @@ class TextVariableWindow(Dialog):
         w = ttk.Button(box, text=CLOSE, style="bg.TButton",  command=self.ok, default=ACTIVE)
         w.pack(side=LEFT, padx=5, pady=5)
         self.bind("<Return>", self.ok)
+        self.bind("<KP_Enter>", self.ok)
         self.bind("<Escape>", self.ok)
         box.pack(side='bottom')
 
@@ -1850,12 +1859,7 @@ class TextDialog(Dialog):
             foreground=self.FGCOLOR,
             takefocus=False)
         self.text.insert("1.1", self.prompt)
-        self.text.pack(side='left', fill=tkinter.BOTH, expand=1, padx=5,
-                       pady=2)
-        # ysb = Scrollbar(master, orient='vertical', command=self.text
-        #                     .yview, width=8)
-        # ysb.pack(side='right', fill=tkinter.Y, expand=0, padx=0, pady=0)
-        # self.text.configure(yscroll=ysb.set)
+        self.text.pack(side='left', fill=tkinter.BOTH, expand=1, padx=5, pady=2)
         return self.text
 
     def buttonbox(self):
@@ -1868,6 +1872,7 @@ class TextDialog(Dialog):
         w.pack(side=LEFT, padx=5, pady=0)
 
         self.bind("<Return>", self.ok)
+        self.bind("<KP_Enter>", self.ok)
         self.bind("<Escape>", self.ok)
 
         box.pack(side='bottom')
@@ -1941,6 +1946,7 @@ class OptionsDialog():
         o.pack(side=LEFT, padx=5, pady=5)
         box.pack()
         self.win.bind('<Return>', (lambda e, o=o: o.invoke()))
+        self.win.bind('<KP_Enter>', (lambda e, o=o: o.invoke()))
         self.win.bind('<Control-w>', self.Ok)
         self.win.bind('<Escape>', (lambda e, c=c: c.invoke()))
         logger.debug('parent: {0}'.format(parent))
@@ -1997,6 +2003,7 @@ class OptionsDialog():
 
 
 class GetInteger(DialogWindow):
+
     def validate(self):
         minvalue = maxvalue = None
         if len(self.options) > 0:
@@ -2029,6 +2036,23 @@ class GetInteger(DialogWindow):
             return False
 
 
+class GetRepeat(GetInteger):
+
+    def buttonbox(self):
+        # add standard button box. override if you don't want the
+        # standard buttons
+        box = Frame(self, background=self.BGCOLOR, highlightcolor=self.HLCOLOR)
+        w = ttk.Button(box, text=_("Repeat"), style="bg.TButton",  command=self.ok, default=ACTIVE)
+        w.pack(side="right", padx=5, pady=2)
+        w = ttk.Button(box, text=_("Close"), style="bg.TButton",  command=self.cancel)
+        w.pack(side="right", padx=5, pady=2)
+        self.bind("<Return>", self.ok)
+        self.bind("<KP_Enter>", self.ok)
+        self.bind("<Escape>", self.cancel)
+
+        box.pack(side='bottom')
+
+
 class GetDateTime(DialogWindow):
     def validate(self):
         res = self.entry.get()
@@ -2041,8 +2065,7 @@ class GetDateTime(DialogWindow):
             ok = True
         else:
             try:
-                # val = parse(parse_datetime(res))
-                val = parse_dt(res)
+                val = parse_str(res)
                 ok = True
             except:
                 val = None
